/***********************************************************************
frogd, daemon pour l'utilisation des capteurs meteo de http://www.froggyhome.com

Copyright (C) 2001 (Regis Barbier)
Ce programme est libre, vous pouvez le redistribuer et/ou le modifier selon 
les termes de la Licence Publique Gnrale GNU publie par la Free Software 
Foundation (version 2 ou bien toute autre version ultrieure choisie par vous).

Ce programme est distribu car potentiellement utile, mais SANS AUCUNE 
GARANTIE, ni explicite ni implicite, y compris les garanties de 
commercialisation ou d'adaptation dans un but spcifique. Reportez-vous  la 
Licence Publique Gnrale GNU pour plus de dtails.

Vous devez avoir reu une copie de la Licence Publique Gnrale GNU en mme 
temps que ce programme. Si ce n'est pas le cas, crivez  la Free Software 
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, tats-Unis.
*************************************************************************/

#ifndef FROG_H
#define FROG_H
  
#include <sys/termios.h>
#include <fcntl.h>
#include <unistd.h>
#include <stdio.h>
#include <sys/ioctl.h>   
#include <string.h>
#include <time.h>
#include <stdlib.h>
#include <math.h>
#include <sys/file.h>
#include "../config.h"

#define TRUE 1
#define FALSE 0

#define FROG_PROG_VERSION VERSION

#define FROG_SPEED  B300
#define FROG_STOPBIT  2
#define FROG_RESET_DELAY 1
#define FROG_MAX_FRAME_SIZE 100
#define FROG_MAX_CHECKSUM_SIZE 5
#define FROG_DEVICE "/dev/ttyS0"
#define FROG_LOG FALSE
#define FROG_LOGFILE "/var/log/frogd.log"
#define FROG_ALTITUDE 0
#define FROG_MIN_PERIOD 70
#define FROG_PERIOD 70
#define FROG_DEBUG FALSE
#define FROG_VERBOSE FALSE
#define FROG_DAEMON TRUE 
#define FROG_READ_DELAY 10
#define FROG_NB_RETRY -1
#define FROG_LOGTYPE "w"
 
#define MAX_SENSOR_DATA 200
#define MAX_SENSOR_NUMBER 3

#define SENSOR_MAX_NAME_SIZE 30
#define SENSOR_MAX_VALUE_NUMBER 3
#define SENSOR_IDENTIFICATION_MASK 0xF0
#define SENSOR_PRES_TEMP 0x10
#define SENSOR_HR  0x30

#define MYSQL_MAX_CHAR_DB 50
#define MYSQL_MAX_CHAR_QUERY 200

#define BEGIN_FRAME 'G'
#define END_FRAME 'Z'

typedef struct  {   
   unsigned char identification;
   char name[SENSOR_MAX_NAME_SIZE];
} SensorType;

typedef struct  {   
   unsigned int identification;
   unsigned int phymesurementsize;
   unsigned int datasize;
   unsigned char data[MAX_SENSOR_DATA];
} Sensor;

  
typedef struct  {   
// config
   int debug;
   int verbose;
   int baud;
   int stopbit;
   int altitude;
   int period;
   char device[100];
   int log;
   char logfile[100];
   int daemon;
   int nbretry;
   char logtype[100];
// identification
   unsigned int firmware;
   unsigned int partnumber;
   unsigned int serialnumber;
   unsigned int nbsensor;   
// data
   int fd;
   Sensor sensor[MAX_SENSOR_NUMBER];
   float lasttemp;
   float lastpress;   
   float lasthum;
  // mysql
  char mysqlhost[MYSQL_MAX_CHAR_DB];
  char mysqldb[MYSQL_MAX_CHAR_DB];
  char mysqluser[MYSQL_MAX_CHAR_DB];
  char mysqlpassword[MYSQL_MAX_CHAR_DB];
  char mysqlquery[MYSQL_MAX_CHAR_QUERY];
  int  logmysql;
} Frog;

//---------------------------------------------------------------
// become a daemon
//---------------------------------------------------------------
int daemonize(void);

//---------------------------------------------------------------
// log the last value generated
//---------------------------------------------------------------
int LogLastResult(Frog* frog);

//---------------------------------------------------------------
// Print the last value generated
//---------------------------------------------------------------
int PrintLastResult(Frog* frog);

//---------------------------------------------------------------
// Initialise the frog structure with the defaults values
// read config file
//---------------------------------------------------------------
int InitFrog(Frog* frog);

//---------------------------------------------------------------
// Print the version and all the data about the frog 
//---------------------------------------------------------------
int PrintIdentification(Frog* frog);

//---------------------------------------------------------------
// Parse the command line to find additionnal arguments
//---------------------------------------------------------------
char parse_cmdline(int argc,char *argv[], Frog* frog);

#endif
